aboutsummaryrefslogtreecommitdiffstats
path: root/packages/meshbay-hub/src/meshbay_hub/static/app.js
diff options
context:
space:
mode:
Diffstat (limited to 'packages/meshbay-hub/src/meshbay_hub/static/app.js')
-rw-r--r--packages/meshbay-hub/src/meshbay_hub/static/app.js8
1 files changed, 5 insertions, 3 deletions
diff --git a/packages/meshbay-hub/src/meshbay_hub/static/app.js b/packages/meshbay-hub/src/meshbay_hub/static/app.js
index 12b48a7..41cc5f2 100644
--- a/packages/meshbay-hub/src/meshbay_hub/static/app.js
+++ b/packages/meshbay-hub/src/meshbay_hub/static/app.js
@@ -944,9 +944,11 @@ function App() {
return () => { gone = true; if (stop) stop(); };
}, [syncAccount]);
// Contacts backup (§9.13), the same way.
useEffect(() => {
- if (!syncAccount || !platform.contactSync.available) return undefined;
+ if (!syncAccount || !(platform.contactSync.available || platform.messageSync.available)) {
+ return undefined;
+ }
let stop = null;
let gone = false;
import('./phone-sync.js').then((m) => {
@@ -962,7 +964,7 @@ function App() {
},
});
stop = m.stopPhoneSync;
- }).catch((e) => console.warn('[MeshBay] contacts backup did not load:', e.message));
+ }).catch((e) => console.warn('[MeshBay] contacts and messages backup did not load:', e.message));
return () => { gone = true; if (stop) stop(); };
}, [syncAccount]);
@@ -944,9 +944,11 @@ function App() {
return () => { gone = true; if (stop) stop(); };
}, [syncAccount]);
- // Contacts backup (§9.13), the same way.
+ // Contacts and messages backup (§9.13), the same way.
useEffect(() => {